@@ -12,7 +12,7 @@
 #include <vector>
 #include <memory>
 
-constexpr auto TESTED_YTMUSICAPI_VERSION = "1.8.2";
+constexpr auto TESTED_YTMUSICAPI_VERSION = "1.10.1";
 
 struct YTMusicPrivate;
 
@@ -177,7 +177,7 @@ namespace album {
         std::string title;
         int track_count;
         std::string duration;
-        std::string audio_playlist_id;
+        std::optional<std::string> audio_playlist_id;
         std::optional<std::string> year;
         std::optional<std::string> description;
         std::vector<meta::Thumbnail> thumbnails;
